@@ -7,10 +7,9 @@ Routines for finding the minimum of a function depending on more than one
 variable.
 
 """
-from  . import _callback
-from pygsl.gsl_function import gsl_multimin_function_fdf, gsl_multimin_function
-from . import _generic_solver  as _generic_solver_module
-_generic_solver = _generic_solver_module._generic_solver
+from . import _callback
+from .gsl_function import gsl_multimin_function_fdf, gsl_multimin_function
+from ._generic_solver import _generic_solver
 
 class _fsolver(_generic_solver):
     type = None
