@@ -13,6 +13,7 @@
 
 #define PyGSL_IMPORT_ARRAY 1
 #include <pygsl/block_helpers.h>
+#include <pygsl/old_numpy_compat.h>
 #include <pygsl/error_helpers.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -145,8 +146,8 @@ PyGSL_PyArray_Check(PyArrayObject *a_array, int array_type, int flag,  int nd,
 {
 
      int i;
-     int error_flag = GSL_ESANITY, line = -1;
-     PyGSL_array_index_t  dim_temp;
+     int error_flag = GSL_ESANITY, line = -1, nd_test, type_num, array_flags;
+     PyGSL_array_index_t  dim_temp, *dimensions_test;
 
      FUNC_MESS_BEGIN();
      if(!PyArray_Check((PyObject *) a_array)){
@@ -163,12 +164,13 @@ PyGSL_PyArray_Check(PyArrayObject *a_array, int array_type, int flag,  int nd,
 	  goto fail;
      }
 
-     if (a_array->nd !=  nd){
-	  DEBUG_MESS(3, "array->nd = %d\t nd = %d", a_array->nd, nd);
+     nd_test = PyArray_NDIM(a_array);
+     if (nd_test !=  nd){
+	  DEBUG_MESS(3, "array->nd = %d\t nd = %d", nd_test, nd);
 	  line = __LINE__ - 1;
 	  sprintf(pygsl_error_str, "I could not convert argument number % 3d."
 		  " I expected a %s, but got an array of % 3d dimensions!\n", argnum, 
-		  (nd == 1) ? "vector" : "matrix", a_array->nd);
+		  (nd == 1) ? "vector" : "matrix", nd_test);
 
 	  if (info){
 	       info->error_description = pygsl_error_str;
@@ -181,6 +183,8 @@ PyGSL_PyArray_Check(PyArrayObject *a_array, int array_type, int flag,  int nd,
      }
      
 
+
+     dimensions_test = PyArray_DIMS(a_array);
      
      for(i=0; i<nd; ++i){
 	  if(dimensions[i] == -1 ){
@@ -203,7 +207,7 @@ PyGSL_PyArray_Check(PyArrayObject *a_array, int array_type, int flag,  int nd,
 	  } 
 
 	  /* Check to be performed ... */
-	  dim_temp = a_array->dimensions[i];
+	  dim_temp = dimensions_test[i];
 	  DEBUG_MESS(9, "Dimension %d has %ld elements", i, 
 		     (unsigned long) dim_temp);
 
@@ -212,7 +216,7 @@ PyGSL_PyArray_Check(PyArrayObject *a_array, int array_type, int flag,  int nd,
 		       "The size of argument % 3d did not match the expected"
 		       " size for the %d dimension. I got % 3ld elements but" 
 		       " expected % 3ld elements!\n",  argnum, i, 
-		       (long)a_array->dimensions[0],(long)dimensions[0]);
+		       (long)dimensions_test[i],(long)dimensions[i]);
 
 	       if (info){
 		    info->error_description = pygsl_error_str;
@@ -226,7 +230,7 @@ PyGSL_PyArray_Check(PyArrayObject *a_array, int array_type, int flag,  int nd,
 	  }
      }
 
-     if(a_array->data == NULL){
+     if(PyArray_DATA(a_array) == NULL){
 	  pygsl_error("Got an array object were the data was NULL!", filename,
 		      __LINE__, GSL_ESANITY);
 	  error_flag = GSL_ESANITY;	  
@@ -234,24 +238,27 @@ PyGSL_PyArray_Check(PyArrayObject *a_array, int array_type, int flag,  int nd,
 	  goto fail;
      }
 
-     if(a_array->descr->type_num == array_type){
+     /* a_array->descr->type_num */
+     type_num = PyArray_TYPE(a_array);
+     if(type_num == array_type){
 	  DEBUG_MESS(4, "\t\tArray type matched! %d", 0);
      }else{
 	  pygsl_error("The array type did not match the spezified one!",
 		      filename, __LINE__, GSL_ESANITY);	  
 	  DEBUG_MESS(4, "Found an array type of %d but expected %d",
-		     (int) a_array->descr->type_num, array_type);
+		     (int) type_num, array_type);
 	  error_flag = GSL_ESANITY;
 	  line = __LINE__ - 6;
 	  goto fail;
      }
 
+     array_flags = PyArray_FLAGS(a_array);
      if ((flag &  PyGSL_CONTIGUOUS) == 0){
 	  DEBUG_MESS(2, "\t\t Can deal with discontiguous arrays! flag = %d", flag);
      } else {
-	  if(!(a_array->flags & CONTIGUOUS)){
+	  if(!(array_flags & CONTIGUOUS)){
 	       DEBUG_MESS(3, "array->flags %d requested flags %d", 
-			  a_array->flags, flag);
+			 array_flags, flag);
 	       pygsl_error("The array is not contiguous as requested!", filename,
 			   __LINE__, GSL_ESANITY);
 	       error_flag = GSL_ESANITY;
@@ -264,24 +271,20 @@ PyGSL_PyArray_Check(PyArrayObject *a_array, int array_type, int flag,  int nd,
 
  fail:
      PyGSL_add_traceback(NULL, filename, __FUNCTION__, line);
-     DEBUG_MESS(4, "common array types: Double %d, CDouble %d", PyArray_DOUBLE, PyArray_CDOUBLE);
-     DEBUG_MESS(4, "integer: Long %d, Int %d, Short %d", PyArray_LONG, PyArray_INT, PyArray_SHORT);
+     PyGSL_ERROR_FLAG(error_flag);
+     DEBUG_MESS(4, "common array types: Double %d, CDouble %d", NPY_DOUBLE, NPY_CDOUBLE);
+     DEBUG_MESS(4, "integer: Long %d, Int %d, Short %d", NPY_LONG, NPY_INT, NPY_SHORT);
      /* DEBUG_MESS(8, "Char type %d  Byte type %d String type %d", PyArray_CHAR, PyArray_BYTE, PyArray_STRING); */
      return error_flag;
 }
 
 
-#ifdef PyGSL_NUMPY
 #include "block_helpers_numpy.ic"
-#endif
-#ifdef PyGSL_NUMERIC
-#include "block_helpers_numeric.ic"
-#endif
-#ifdef PyGSL_NUMARRAY
-#include "block_helpers_numarray.ic"
-#endif
-#if (!defined PyGSL_NUMPY) && (!defined  PyGSL_NUMERIC) && (! defined PyGSL_NUMARRAY)
-#error "Neither numpy nor numarray nor numeric is defined!"
+
+#ifdef PyGSL_PY3K
+#define _PyGSL_WRAP_LONG_FROM_PyObject(src) PyLong_AS_LONG(((src)))
+#else
+#define _PyGSL_WRAP_LONG_FROM_PyObject(src) ( PyInt_AsLong(((src))) )
 #endif
 
 static PyArrayObject * 
@@ -294,17 +297,18 @@ PyGSL_PyArray_generate_gsl_vector_view(PyObject *src,
      PyArrayObject *a_array = NULL;
 
      FUNC_MESS_BEGIN();
-     tmp = PyNumber_Int(src);
+     tmp = PyNumber_Long(src);
      if(!tmp){
 	  sprintf(pygsl_error_str, "I could not convert argument number % 3d. to an integer.",
 		  argnum);
 	 PyErr_SetString(PyExc_TypeError, pygsl_error_str);
 	 return NULL;
      }
-     dimension = PyInt_AS_LONG(src);
+     dimension = _PyGSL_WRAP_LONG_FROM_PyObject(src);
      Py_DECREF(tmp);
      if(dimension <= 0){
-	  sprintf(pygsl_error_str, "Argument number % 3d is % 10ld< 0. Its the size of the vector and thus must be positive!",
+	  sprintf(pygsl_error_str, 
+		  "Argument number % 3d is % 10ld< 0. Its the size of the vector and thus must be positive!",
 		  argnum, (long)dimension);
 	 PyErr_SetString(PyExc_TypeError, pygsl_error_str);
 	 return NULL;
@@ -339,14 +343,15 @@ PyGSL_PyArray_generate_gsl_matrix_view(PyObject *src,
      }
 
      for(i = 0; i<2; i++){
-	  tmp = PyNumber_Int(PySequence_GetItem(src, i));
+          tmp = PyNumber_Long(PySequence_GetItem(src, i));
 	  if(!tmp){
 	       sprintf(pygsl_error_str, "I could not convert argument number % 3d. for dimension %3d to an integer.",
 		       argnum, i);
 	       PyErr_SetString(PyExc_TypeError, pygsl_error_str);
 	       return NULL;
 	  }
-	  dimensions[i] = PyInt_AS_LONG(tmp);
+
+	  dimensions[i] = _PyGSL_WRAP_LONG_FROM_PyObject(tmp);
 	  Py_DECREF(tmp);
 	  if(dimensions[i] <= 0){
 	       sprintf(pygsl_error_str, "Argument number % 3d is % 10ld< 0. Its the size of the vector and thus must be positive!",
@@ -355,7 +360,10 @@ PyGSL_PyArray_generate_gsl_matrix_view(PyObject *src,
 	       return NULL;
 	  }
 
-     }     
+     }
+     DEBUG_MESS(2, "Creating an array for a matrix with dimensions %ld %ld",
+		(long) dimensions[0], (long) dimensions[1]);
+
      a_array = (PyArrayObject *) PyGSL_New_Array(2, dimensions, array_type);
      if(NULL == a_array){
 	  return NULL;
@@ -368,15 +376,17 @@ PyGSL_copy_gslvector_to_pyarray(const gsl_vector *x)
 {     
      PyGSL_array_index_t dimension = -1, i;
      PyArrayObject *a_array = NULL;
-     double tmp;
+     double tmp, *ptr = NULL;
 
      FUNC_MESS_BEGIN();
      dimension = x->size;
-     a_array = (PyArrayObject *) PyGSL_New_Array(1, &dimension, PyArray_DOUBLE);
+     a_array = (PyArrayObject *) PyGSL_New_Array(1, &dimension, NPY_DOUBLE);
      if (a_array == NULL) return NULL;
+
+     ptr = ((double *) PyArray_DATA(a_array));
      for (i=0;i<dimension;i++){
        tmp = gsl_vector_get(x, i);
-       ((double *) a_array->data)[i] = tmp;
+       ptr[i] = tmp;
        DEBUG_MESS(3, "\t\ta_array_%ld = %f\n", (long)i, tmp);
      }
      FUNC_MESS_END();
@@ -387,20 +397,22 @@ static PyArrayObject *
 PyGSL_copy_gslmatrix_to_pyarray(const gsl_matrix *x)
 {     
      int i, j;
-     PyGSL_array_index_t dimensions[2];
+     PyGSL_array_index_t dimensions[2],  *strides;
      PyArrayObject *a_array = NULL;
      double tmp;
-     char *myptr;
+     char *myptr, *data=NULL;
 
      FUNC_MESS_BEGIN();
      dimensions[0] = x->size1;
      dimensions[1] = x->size2;
-     a_array = (PyArrayObject *) PyGSL_New_Array(2, dimensions, PyArray_DOUBLE);
+     a_array = (PyArrayObject *) PyGSL_New_Array(2, dimensions, NPY_DOUBLE);
      if (a_array == NULL) return NULL;
+
+     strides = PyArray_STRIDES(a_array);
+     data = (char *) PyArray_DATA(a_array);
      for (i=0;i<dimensions[1];i++){
 	  for (j=0;j<dimensions[0];j++){
-	      myptr =  a_array->data + a_array->strides[0] * i  
-		                     + a_array->strides[1] * j;
+	      myptr =  data + strides[0] * i + strides[1] * j;
 	       tmp = gsl_matrix_get(x, j, i);
 	       *((double *) myptr) = tmp;
 	       DEBUG_MESS(3, "\t\ta_array_%d = %f\n", i, tmp);
@@ -421,7 +433,9 @@ PyGSL_copy_pyarray_to_gslvector(gsl_vector *f, PyObject *object,  PyGSL_array_in
      PyArrayObject *a_array = NULL;
      double tmp;
      int i, argnum = -1;
+     char *data;
      
+     PyGSL_array_index_t *dimensions =NULL,  *strides = NULL;
 
      FUNC_MESS_BEGIN();
      if (info)
@@ -431,13 +445,17 @@ PyGSL_copy_pyarray_to_gslvector(gsl_vector *f, PyObject *object,  PyGSL_array_in
           FUNC_MESS("PyArray_FromObject failed");
 	  goto fail;
      }
-    if(DEBUG>2){
-      fprintf(stderr, "\t\ta_array->dimensions[0] = %d\n", a_array->dimensions[0]);
-      fprintf(stderr, "\t\ta_array->strides[0] = %d\n", a_array->strides[0]);
-    }
+
+
+     dimensions = PyArray_DIMS(a_array);
+     strides = PyArray_STRIDES(a_array);
+     data = (char *) PyArray_DATA(a_array);
+     
+     DEBUG_MESS(2, "\t\ta_array->dimensions[0] = %ld\n\t\ta_array->strides[0] = %ld",
+		(long)dimensions[0], (long)strides[0]);
 
     for (i=0;i<n;i++){
-	 tmp = *((double *) (a_array->data + a_array->strides[0] * i));
+	 tmp = *((double *) (data + strides[0] * i));
 	 gsl_vector_set(f, i, tmp);
 	 DEBUG_MESS(3, "\t\ta_array_%d = %f\n", i, tmp);
 
@@ -461,31 +479,35 @@ PyGSL_copy_pyarray_to_gslmatrix(gsl_matrix *f, PyObject *object,  PyGSL_array_in
 {
      PyArrayObject *a_array = NULL;
      double tmp;
-     char *myptr;
+     char *myptr, *data=NULL;
      int argnum=-1;
-     long i, j;
-
+     PyGSL_array_index_t *dimensions,  *strides, i, j;
 
      FUNC_MESS_BEGIN();
 
 
      
-     if (info)
+     if (info){
 	  argnum = info->argnum;
+     }
+     
      a_array = PyGSL_matrix_check(object, n, p, PyGSL_DARRAY_CINPUT(info->argnum), NULL, NULL, info);
      if(a_array == NULL){
 	  FUNC_MESS(" PyGSL_PyArray_PREPARE_gsl_matrix_view failed!");
 	  goto fail;
      }
 
+     
     assert(f->size1 == (size_t) n);
     assert(f->size2 == (size_t) p);
 
+    strides = PyArray_STRIDES(a_array);
+    dimensions = PyArray_DIMS(a_array);
+    data = (char *) PyArray_DATA(a_array);
 
     for (i=0;i<n;i++){
 	 for (j=0;j<p;j++){
-	      myptr =  a_array->data + a_array->strides[0] * i  
-		                     + a_array->strides[1] * j;
+	      myptr =  data + strides[0] * i + strides[1] * j;
 	      tmp = *((double *)(myptr));
 	      DEBUG_MESS(3, "\t\ta_array[%ld,%ld] = %f\n", i, j, tmp);
 	      gsl_matrix_set(f, i, j, tmp);
@@ -496,7 +518,7 @@ PyGSL_copy_pyarray_to_gslmatrix(gsl_matrix *f, PyObject *object,  PyGSL_array_in
     return GSL_SUCCESS;
  fail:
     PyGSL_add_traceback(NULL, filename, __FUNCTION__, __LINE__);
-    FUNC_MESS("  Failure");
+    FUNC_MESS_FAILED();
     Py_XDECREF(a_array);
     return GSL_FAILURE;
 }
@@ -504,21 +526,23 @@ PyGSL_copy_pyarray_to_gslmatrix(gsl_matrix *f, PyObject *object,  PyGSL_array_in
 static PyArrayObject * 
 PyGSL_vector_or_double(PyObject *src, PyGSL_array_info_t ainfo, PyGSL_array_index_t size, PyGSL_error_info * info)
 {
-     int line = -1;
+  int line = -1, status = GSL_EFAILED;
      PyArrayObject * r = NULL;
      PyGSL_array_index_t dim = 1;
 
      FUNC_MESS_BEGIN();
-     if (PyGSL_GET_ARRAYTYPE(ainfo) != PyArray_DOUBLE){
+     if (PyGSL_GET_ARRAYTYPE(ainfo) != NPY_DOUBLE){
 	  line = __LINE__ - 1;
+	  status = GSL_ESANITY;
 	  pygsl_error("Array request for vector or double is not a double array!",
-		    __FILE__, line, GSL_ESANITY);
+		    __FILE__, line, status);
 	  goto fail;
      }
      if (PyGSL_GET_TYPESIZE(ainfo)  != sizeof(double)){
 	  line = __LINE__ - 1;
+	  status = GSL_ESANITY;
 	  pygsl_error("Type size passed for vector or double is not of sizeof(double)!",
-		    __FILE__, line, GSL_ESANITY);
+		    __FILE__, line, status);
 	  goto fail;
      }
 	  
@@ -535,20 +559,21 @@ PyGSL_vector_or_double(PyObject *src, PyGSL_array_info_t ainfo, PyGSL_array_inde
 	       goto fail;	    
 	  }	 
 	  FUNC_MESS("=> FLOAT");
-	  r = (PyArrayObject *) PyGSL_New_Array(1, &dim, PyArray_DOUBLE);
+	  r = (PyArrayObject *) PyGSL_New_Array(1, &dim, NPY_DOUBLE);
 	  if(r == NULL) {
 	       line = __LINE__ - 2;
 	       goto fail;
 	  }
-	  (*(double *)(r->data)) = v;
+	  (*(double *)PyArray_DATA(r)) = v;
      }
      FUNC_MESS_END();
      return r;
 
  fail:
-     PyGSL_add_traceback(NULL, filename, __FUNCTION__, line);
+     FUNC_MESS_FAILED();
      Py_XDECREF(r);
-     FUNC_MESS("Fail");
+     PyGSL_add_traceback(NULL, filename, __FUNCTION__, line);
+     PyGSL_ERROR_FLAG(status);
      return NULL;
 }
 
@@ -559,10 +584,11 @@ PyGSL_vector_check(PyObject *src, PyGSL_array_index_t size,
 		   PyGSL_array_index_t *stride, PyGSL_error_info * info)
 {
 
-     int line=-1, tries;
+  int line=-1, tries, status = GSL_EFAILED;
      PyArrayObject * a_array = NULL;
      int array_type, flag,  argnum, type_size;
 
+     PyGSL_array_index_t *dimensions,  *strides;
 	  
 	  
      FUNC_MESS_BEGIN();
@@ -607,7 +633,9 @@ PyGSL_vector_check(PyObject *src, PyGSL_array_index_t size,
 	       break; /* will return array */
 	  }
 
-	  if(PyGSL_STRIDE_RECALC(a_array->strides[0], type_size, stride) == GSL_SUCCESS){
+	  strides = PyArray_STRIDES(a_array);
+	      
+	  if(PyGSL_STRIDE_RECALC(strides[0], type_size, stride) == GSL_SUCCESS){
 	       /* everybody happy I hope! */
 	       if((flag & PyGSL_CONTIGUOUS) == 1){
 		    /* 
@@ -617,8 +645,9 @@ PyGSL_vector_check(PyObject *src, PyGSL_array_index_t size,
 		    if(PyGSL_DEBUG_LEVEL() > 0){
 			 if(*stride != 1){
 			      line = __LINE__ - 1;
+			      status = GSL_ESANITY;
 			      pygsl_error("Stride not one for a contiguous array!",
-					filename, line, GSL_ESANITY);
+					filename, line, status);
 			      goto fail;
 			 } /* stride */
 		    }/*debug level */
@@ -629,12 +658,13 @@ PyGSL_vector_check(PyObject *src, PyGSL_array_index_t size,
      
 	  /* Lets try to see if it makes sense to meake a copy */
 	  DEBUG_MESS(2, "Stride recalc failed type size is  %ld, array stride[0] is %ld",
-		     (long)type_size, (long)a_array->strides[0]);
+		     (long)type_size, (long)strides[0]);
 
 	  if((flag & PyGSL_CONTIGUOUS) == 1){
 	       line = __LINE__ - 1;
+	       status = GSL_ESANITY;
 	       pygsl_error("Why does the stride recalc fail for a contigous array?",
-			 filename, line, GSL_ESANITY);
+			 filename, line, status);
 	       goto fail;
 	  } else {
 	       /* keep the flags, but demand contiguous this time */
@@ -645,16 +675,18 @@ PyGSL_vector_check(PyObject *src, PyGSL_array_index_t size,
 	  }
 
      }/* number of tries */
-     DEBUG_MESS(7, "Checking refcount src obj @ %p had %d cts and array @ %p has now %d cts", 
-		(void *) src, src->ob_refcnt, (void *)a_array, a_array->ob_refcnt);
+     DEBUG_MESS(7, "Checking refcount src obj @ %p had %ld cts and array @ %p has now %ld cts", 
+		(void *) src,  src->ob_refcnt, (void *)a_array, 
+		PyGSL_PY_ARRAY_GET_REFCNT(a_array));
     	  
     /* handling failed stride recalc */
      FUNC_MESS_END();
-
+    
      return a_array;
      
  fail:
      FUNC_MESS("Fail");
+     PyGSL_ERROR_FLAG(status);
      PyGSL_add_traceback(NULL, filename, __FUNCTION__, line);
      Py_XDECREF(a_array);
      return NULL;
@@ -680,6 +712,7 @@ PyGSL_matrix_check(PyObject *src, PyGSL_array_index_t size1, PyGSL_array_index_t
      PyArrayObject * a_array = NULL;
      PyGSL_array_index_t * stride;
      int array_type, flag,  argnum, type_size;
+     PyGSL_array_index_t *dimensions,  *strides;
 
      FUNC_MESS_BEGIN();
 
@@ -695,7 +728,7 @@ PyGSL_matrix_check(PyObject *src, PyGSL_array_index_t size1, PyGSL_array_index_t
       * a contiguous array is demanded.
       */
      for(tries = 0; tries <2; ++tries){
-#if 0	  
+#if 0 
 	  a_array = PyGSL_MATRIX_CONVERT(src, array_type, flag);
 	  if(a_array !=  NULL && a_array->nd == 1 && 
 	     (size1 == -1 || a_array->dimensions[0] == size1) &&
@@ -720,6 +753,8 @@ PyGSL_matrix_check(PyObject *src, PyGSL_array_index_t size1, PyGSL_array_index_t
 		    goto fail;
 	       }
 	  }
+
+	  strides = PyArray_STRIDES(a_array);
 	  for(j = 0; j<2; ++j){
 	       switch(j){
 	       case 0:  stride = stride1; break;
@@ -732,7 +767,8 @@ PyGSL_matrix_check(PyObject *src, PyGSL_array_index_t size1, PyGSL_array_index_t
 		    continue;
 	       }
 
-	       if(PyGSL_STRIDE_RECALC(a_array->strides[j], type_size, stride) == GSL_SUCCESS){
+	       
+	       if(PyGSL_STRIDE_RECALC(strides[j], type_size, stride) == GSL_SUCCESS){
 		    /* everybody happy I hope! */
 		    if((flag & PyGSL_CONTIGUOUS) == 1){
 			 /* 
@@ -745,7 +781,7 @@ PyGSL_matrix_check(PyObject *src, PyGSL_array_index_t size1, PyGSL_array_index_t
 			      line = __LINE__ - 1;
 			      DEBUG_MESS(6, "array stride %ld, type size %d, "
 					 "found a stride of %ld", 
-					 (long) a_array->strides[j], type_size, (long) *stride);
+					 (long) strides[j], type_size, (long) *stride);
 			      pygsl_error("Stride not one of a contiguous array!",
 				   filename, line, GSL_ESANITY);
 			      goto fail;
@@ -754,7 +790,7 @@ PyGSL_matrix_check(PyObject *src, PyGSL_array_index_t size1, PyGSL_array_index_t
 	       } else {         
 		    /* Lets try to see if it makes sense to meake a copy */
 		    DEBUG_MESS(2, "Stride recalc failed type size is  %ld, array stride[0] is %ld",
-			       (long)type_size, (long)a_array->strides[j]);
+			       (long)type_size, (long)strides[j]);
 		    
 		    if((flag & PyGSL_CONTIGUOUS) == 1){
 			 line = __LINE__ - 1;
