@@ -1,83 +1,10 @@
-#include <Python.h>
-#define NPY_NO_DEPRECATED_API NPY_1_7_API_VERSION
-#include <numpy/arrayobject.h>
-
-#include <gsl/gsl_complex.h>
 #include <pygsl/intern.h>
 #include <pygsl/utils.h>
 #include <pygsl/error_helpers.h>
 #include <pygsl/block_helpers.h>
-#include <pygsl/string_helpers.h>
 
 static PyObject * module = NULL;
 
-static PyObject*
-PyGSL_test_any_array(PyObject *self, PyObject *args)
-{
-	PyObject *result = NULL;
-	PyArrayObject * a = NULL;
-	const char *msg = NULL;
-	int type_num, basis_size;
-
-	const int requirements = NPY_ARRAY_NOTSWAPPED | NPY_ARRAY_ELEMENTSTRIDES | NPY_ARRAY_ENSURECOPY;
-	a = (PyArrayObject *) PyArray_CheckFromAny(args, NULL, 0, 0, requirements, NULL);
-	if (a == NULL){
-		goto fail;
-	}
-
-	type_num = PyArray_TYPE(a);
-	switch(type_num){
-	case NPY_CLONGDOUBLE: msg = "complex long double"; break;
-	case NPY_CDOUBLE:     msg = "complex double"; break;
-	case NPY_CFLOAT:      msg = "complex float";  break;
-	case NPY_LONGDOUBLE:  msg = "long double";    break;
-	case NPY_DOUBLE:      msg = "double"; break;
-	case NPY_FLOAT:       msg = "float";  break;
-	case NPY_LONGLONG:    msg = "long long";   break;
-	case NPY_LONG:        msg = "long";   break;
-	case NPY_SHORT:       msg = "short";   break;
-	case NPY_BYTE:        msg = "byte";   break;
-	case NPY_ULONGLONG:   msg = "unsigend long long";   break;
-	case NPY_ULONG:       msg = "unsigned long";    break;
-	case NPY_UINT:        msg = "unsigned int";    break;
-	case NPY_USHORT:      msg = "unsigned short";    break;
-	case NPY_UBYTE:       msg = "unsigned byte";    break;
-	case NPY_OBJECT:      msg = "object";    break;
-	default:
-		msg = "unknown";
-	}
-
-	switch(type_num){
-	case NPY_CLONGDOUBLE: basis_size = sizeof(gsl_complex_long_double); break;
-	case NPY_CDOUBLE:     basis_size = sizeof(gsl_complex);      break;
-	case NPY_CFLOAT:      basis_size = sizeof(gsl_complex_float);       break;
-	case NPY_LONGDOUBLE:  basis_size = sizeof(long double);         break;
-	case NPY_DOUBLE:      basis_size = sizeof(double);              break;
-	case NPY_FLOAT:       basis_size = sizeof(float);               break;
-	case NPY_LONGLONG:    basis_size = sizeof(long long);           break;
-	case NPY_LONG:        basis_size = sizeof(long);                break;
-	case NPY_SHORT:       basis_size = sizeof(short);               break;
-	case NPY_BYTE:        basis_size = sizeof(char);                break;
-	case NPY_ULONGLONG:   basis_size = sizeof(unsigned long long);  break;
-	case NPY_ULONG:       basis_size = sizeof(unsigned long);       break;
-	case NPY_UINT:        basis_size = sizeof(unsigned int);        break;
-	case NPY_USHORT:      basis_size = sizeof(unsigned short);      break;
-	case NPY_UBYTE:       basis_size = sizeof(unsigned char);       break;
-	default:
-		msg = "unknown";
-	}
-	
-	result = PyGSL_string_from_string(msg);
-	if(result == NULL){
-		goto fail;
-	}
-	Py_DECREF(a);
-	return result;
-	
-  fail:
-	Py_XDECREF(a);
-	return NULL;
-}
 static PyObject*
 PyGSL_test_GetPTR1(PyObject *self, PyObject *args)
 {
@@ -249,7 +176,6 @@ static PyMethodDef inittestMethods[] = {
      {"new_array", PyGSL_test_new_array, METH_VARARGS, new_array_doc},
      {"vector_or_double", PyGSL_test_vector_or_double, METH_VARARGS, vector_or_double_doc},
      {"test_getptr1",    PyGSL_test_GetPTR1, METH_VARARGS, test_getptr1_doc},
-     {"test_any_array", PyGSL_test_any_array, METH_O, NULL},
      {NULL,     NULL, 0, NULL}        /* sentinel */
 };  
 
@@ -291,7 +217,6 @@ DL_EXPORT(void) initinittest(void)
 
   FUNC_MESS_BEGIN();
   module = m;
-  import_array();
   init_pygsl();
 
   FUNC_MESS_END();
