@@ -9,11 +9,11 @@ class P(unittest.TestCase):
         self.p = permutation.Permutation(self.mylen)
 
     def testlen(self):
-        assert(type(len(self.p)) == types.IntType)
+        assert(type(len(self.p)) == type(1))
         assert(len(self.p) == self.mylen)
 
-    def testinversions(self):
-        self.p.inversions()
+    def testinverse(self):
+        self.p.inverse()
 
     def testlinearcycles(self):
         self.p.linear_cycles()
